==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueStringValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueStringValueFluent<A extends ValueStringValueFluent<A>> extends BaseFluent<A>{
  public ValueStringValueFluent() {
  }
  public ValueStringValueFluent(ValueStringValue instance) {
    instance = (instance != null ? instance : new ValueStringValue());

    if (instance != null) {
      this.withStringValue(instance.getStringValue());
      this.withStringValue(instance.getStringValue());
    }
  }
  private String stringValue;
  public String getStringValue() {
    return this.stringValue;
  }
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  public boolean hasStringValue() {
    return this.stringValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueStringValueFluent that = (ValueStringValueFluent) o;
    if (!java.util.Objects.equals(stringValue, that.stringValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(stringValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueStringValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueStringValueFluent<A extends ValueStringValueFluent<A>> extends BaseFluent<A>{
  public ValueStringValueFluent() {
  }
  
  public ValueStringValueFluent(ValueStringValue instance) {
    this.copyInstance(instance);
  }
  private String stringValue;
  
  protected void copyInstance(ValueStringValue instance) {
    instance = (instance != null ? instance : new ValueStringValue());
  
    if (instance != null) {
        this.withStringValue(instance.getStringValue());
        this.withStringValue(instance.getStringValue());
      }
  }
  
  public String getStringValue() {
    return this.stringValue;
  }
  
  public A withStringValue(String stringValue) {
    this.stringValue=stringValue; return (A) this;
  }
  
  public boolean hasStringValue() {
    return this.stringValue != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueStringValueFluent that = (ValueStringValueFluent) o;
    if (!java.util.Objects.equals(stringValue, that.stringValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(stringValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (stringValue != null) { sb.append("stringValue:"); sb.append(stringValue); }
    sb.append("}");
    return sb.toString();
  }
  

}
